@@ -1,9 +1,5 @@
 var NAVTREEINDEX1 =
 {
-"packages.html#PkgPartition2":[2,4,5],
-"packages.html#PkgPeriodic2Triangulation2":[2,7,3],
-"packages.html#PkgPeriodic3Mesh3":[2,9,6],
-"packages.html#PkgPeriodic3Triangulation3":[2,7,8],
 "packages.html#PkgPeriodic4HyperbolicTriangulation2":[2,7,5],
 "packages.html#PkgPointSet2":[2,12,0],
 "packages.html#PkgPointSet3":[2,11,11],
@@ -68,83 +64,57 @@ var NAVTREEINDEX1 =
 "preliminaries.html#Preliminaries_thread_safety":[0,7,1],
 "preliminaries.html#preliminaries_secchecks":[0,7,3],
 "preliminaries.html#seccgal_version":[0,7,5],
-"thirdparty.html":[0,3,2],
-"thirdparty.html":[3,17,0,2],
 "thirdparty.html":[0,2],
-"thirdparty.html#seccmake":[0,3,2,1],
+"thirdparty.html":[0,3,2],
 "thirdparty.html#seccmake":[0,2,1],
-"thirdparty.html#seccmake":[3,17,0,2,1],
+"thirdparty.html#seccmake":[0,3,2,1],
 "thirdparty.html#seccompilers":[0,2,0],
 "thirdparty.html#seccompilers":[0,3,2,0],
-"thirdparty.html#seccompilers":[3,17,0,2,0],
-"thirdparty.html#secessential3rdpartysoftware":[0,3,2,2],
 "thirdparty.html#secessential3rdpartysoftware":[0,2,2],
-"thirdparty.html#secessential3rdpartysoftware":[3,17,0,2,2],
-"thirdparty.html#secoptional3rdpartysoftware":[0,3,2,3],
+"thirdparty.html#secessential3rdpartysoftware":[0,3,2,2],
 "thirdparty.html#secoptional3rdpartysoftware":[0,2,3],
-"thirdparty.html#secoptional3rdpartysoftware":[3,17,0,2,3],
-"thirdparty.html#thirdpartyBoost":[0,3,2,2,1],
+"thirdparty.html#secoptional3rdpartysoftware":[0,3,2,3],
 "thirdparty.html#thirdpartyBoost":[0,2,2,1],
-"thirdparty.html#thirdpartyBoost":[3,17,0,2,2,1],
-"thirdparty.html#thirdpartyCeres":[3,17,0,2,3,14],
-"thirdparty.html#thirdpartyCeres":[0,2,3,14],
+"thirdparty.html#thirdpartyBoost":[0,3,2,2,1],
 "thirdparty.html#thirdpartyCeres":[0,3,2,3,14],
-"thirdparty.html#thirdpartyESBTL":[0,3,2,3,8],
-"thirdparty.html#thirdpartyESBTL":[3,17,0,2,3,8],
-"thirdparty.html#thirdpartyESBTL":[0,2,3,8],
-"thirdparty.html#thirdpartyEigen":[3,17,0,2,3,1],
-"thirdparty.html#thirdpartyEigen":[0,3,2,3,1],
+"thirdparty.html#thirdpartyCeres":[0,2,3,14],
+"thirdparty.html#thirdpartyESBTL":[0,3,2,3,7],
+"thirdparty.html#thirdpartyESBTL":[0,2,3,7],
 "thirdparty.html#thirdpartyEigen":[0,2,3,1],
-"thirdparty.html#thirdpartyGLPK":[0,2,3,15],
-"thirdparty.html#thirdpartyGLPK":[3,17,0,2,3,15],
+"thirdparty.html#thirdpartyEigen":[0,3,2,3,1],
 "thirdparty.html#thirdpartyGLPK":[0,3,2,3,15],
-"thirdparty.html#thirdpartyLASlib":[0,3,2,3,10],
-"thirdparty.html#thirdpartyLASlib":[3,17,0,2,3,10],
-"thirdparty.html#thirdpartyLASlib":[0,2,3,10],
-"thirdparty.html#thirdpartyLeda":[0,2,3,4],
-"thirdparty.html#thirdpartyLeda":[0,3,2,3,4],
-"thirdparty.html#thirdpartyLeda":[3,17,0,2,3,4],
+"thirdparty.html#thirdpartyGLPK":[0,2,3,15],
+"thirdparty.html#thirdpartyLASlib":[0,3,2,3,9],
+"thirdparty.html#thirdpartyLASlib":[0,2,3,9],
 "thirdparty.html#thirdpartyMETIS":[0,3,2,3,12],
 "thirdparty.html#thirdpartyMETIS":[0,2,3,12],
-"thirdparty.html#thirdpartyMETIS":[3,17,0,2,3,12],
-"thirdparty.html#thirdpartyMP":[0,2,2,2],
 "thirdparty.html#thirdpartyMP":[0,3,2,2,2],
-"thirdparty.html#thirdpartyMP":[3,17,0,2,2,2],
-"thirdparty.html#thirdpartyMPFI":[0,2,3,5],
-"thirdparty.html#thirdpartyMPFI":[3,17,0,2,3,5],
-"thirdparty.html#thirdpartyMPFI":[0,3,2,3,5],
-"thirdparty.html#thirdpartyNTL":[3,17,0,2,3,7],
-"thirdparty.html#thirdpartyNTL":[0,3,2,3,7],
-"thirdparty.html#thirdpartyNTL":[0,2,3,7],
-"thirdparty.html#thirdpartyOSQP":[0,2,3,17],
-"thirdparty.html#thirdpartyOSQP":[3,17,0,2,3,17],
+"thirdparty.html#thirdpartyMP":[0,2,2,2],
+"thirdparty.html#thirdpartyMPFI":[0,3,2,3,4],
+"thirdparty.html#thirdpartyMPFI":[0,2,3,4],
+"thirdparty.html#thirdpartyNTL":[0,2,3,6],
+"thirdparty.html#thirdpartyNTL":[0,3,2,3,6],
 "thirdparty.html#thirdpartyOSQP":[0,3,2,3,17],
-"thirdparty.html#thirdpartyOpenCV":[3,17,0,2,3,11],
-"thirdparty.html#thirdpartyOpenCV":[0,3,2,3,11],
-"thirdparty.html#thirdpartyOpenCV":[0,2,3,11],
+"thirdparty.html#thirdpartyOSQP":[0,2,3,17],
+"thirdparty.html#thirdpartyOpenCV":[0,3,2,3,10],
+"thirdparty.html#thirdpartyOpenCV":[0,2,3,10],
 "thirdparty.html#thirdpartyOpenGR":[0,3,2,3,2],
 "thirdparty.html#thirdpartyOpenGR":[0,2,3,2],
-"thirdparty.html#thirdpartyOpenGR":[3,17,0,2,3,2],
 "thirdparty.html#thirdpartyQt":[0,3,2,3,0],
 "thirdparty.html#thirdpartyQt":[0,2,3,0],
-"thirdparty.html#thirdpartyQt":[3,17,0,2,3,0],
-"thirdparty.html#thirdpartyRS3":[3,17,0,2,3,6],
-"thirdparty.html#thirdpartyRS3":[0,2,3,6],
-"thirdparty.html#thirdpartyRS3":[0,3,2,3,6],
-"thirdparty.html#thirdpartySCIP":[0,3,2,3,16],
-"thirdparty.html#thirdpartySCIP":[3,17,0,2,3,16],
+"thirdparty.html#thirdpartyRS3":[0,3,2,3,5],
+"thirdparty.html#thirdpartyRS3":[0,2,3,5],
 "thirdparty.html#thirdpartySCIP":[0,2,3,16],
-"thirdparty.html#thirdpartyTBB":[0,2,3,9],
-"thirdparty.html#thirdpartyTBB":[0,3,2,3,9],
-"thirdparty.html#thirdpartyTBB":[3,17,0,2,3,9],
-"thirdparty.html#thirdpartylibpointmatcher":[3,17,0,2,3,3],
+"thirdparty.html#thirdpartySCIP":[0,3,2,3,16],
+"thirdparty.html#thirdpartySuiteSparse":[0,3,2,3,11],
+"thirdparty.html#thirdpartySuiteSparse":[0,2,3,11],
+"thirdparty.html#thirdpartyTBB":[0,2,3,8],
+"thirdparty.html#thirdpartyTBB":[0,3,2,3,8],
 "thirdparty.html#thirdpartylibpointmatcher":[0,3,2,3,3],
 "thirdparty.html#thirdpartylibpointmatcher":[0,2,3,3],
 "thirdparty.html#thirdpartystl":[0,2,2,0],
 "thirdparty.html#thirdpartystl":[0,3,2,2,0],
-"thirdparty.html#thirdpartystl":[3,17,0,2,2,0],
 "thirdparty.html#thirdpartyzlib":[0,3,2,3,13],
-"thirdparty.html#thirdpartyzlib":[3,17,0,2,3,13],
 "thirdparty.html#thirdpartyzlib":[0,2,3,13],
 "tuto_gis.html":[1,4],
 "tuto_gis.html#TutorialGIS_Classify":[1,4,5],
