@@ -1,54 +1,57 @@
 var NAVTREEINDEX0 =
 {
-"Poisson_surface_reconstruction_3_2poisson_reconstruction_example_8cpp-example.html":[5,25],
-"Polygon_mesh_processing_2cc_compatible_orientations_8cpp-example.html":[5,43],
+"Poisson_surface_reconstruction_3_2poisson_reconstruction_example_8cpp-example.html":[5,29],
+"Polygon_mesh_processing_2cc_compatible_orientations_8cpp-example.html":[5,47],
 "Polygon_mesh_processing_2compute_normals_example_8cpp-example.html":[5,9],
-"Polygon_mesh_processing_2compute_normals_example_Polyhedron_8cpp-example.html":[5,23],
+"Polygon_mesh_processing_2compute_normals_example_Polyhedron_8cpp-example.html":[5,27],
 "Polygon_mesh_processing_2connected_components_example_8cpp-example.html":[5,12],
-"Polygon_mesh_processing_2corefinement_OM_union_8cpp-example.html":[5,29],
-"Polygon_mesh_processing_2corefinement_consecutive_bool_op_8cpp-example.html":[5,31],
-"Polygon_mesh_processing_2corefinement_difference_remeshed_8cpp-example.html":[5,26],
-"Polygon_mesh_processing_2corefinement_mesh_union_8cpp-example.html":[5,27],
-"Polygon_mesh_processing_2corefinement_mesh_union_and_intersection_8cpp-example.html":[5,30],
-"Polygon_mesh_processing_2corefinement_mesh_union_progress_8cpp-example.html":[5,28],
-"Polygon_mesh_processing_2delaunay_remeshing_example_8cpp-example.html":[5,22],
-"Polygon_mesh_processing_2detect_features_example_8cpp-example.html":[5,32],
+"Polygon_mesh_processing_2corefinement_OM_union_8cpp-example.html":[5,33],
+"Polygon_mesh_processing_2corefinement_consecutive_bool_op_8cpp-example.html":[5,35],
+"Polygon_mesh_processing_2corefinement_difference_remeshed_8cpp-example.html":[5,30],
+"Polygon_mesh_processing_2corefinement_mesh_union_8cpp-example.html":[5,31],
+"Polygon_mesh_processing_2corefinement_mesh_union_and_intersection_8cpp-example.html":[5,34],
+"Polygon_mesh_processing_2corefinement_mesh_union_progress_8cpp-example.html":[5,32],
+"Polygon_mesh_processing_2delaunay_remeshing_example_8cpp-example.html":[5,26],
+"Polygon_mesh_processing_2detect_features_example_8cpp-example.html":[5,36],
 "Polygon_mesh_processing_2extrude_8cpp-example.html":[5,0],
 "Polygon_mesh_processing_2face_filtered_graph_example_8cpp-example.html":[5,13],
-"Polygon_mesh_processing_2hausdorff_bounded_error_distance_example_8cpp-example.html":[5,42],
-"Polygon_mesh_processing_2hausdorff_distance_remeshing_example_8cpp-example.html":[5,24],
+"Polygon_mesh_processing_2hausdorff_bounded_error_distance_example_8cpp-example.html":[5,46],
+"Polygon_mesh_processing_2hausdorff_distance_remeshing_example_8cpp-example.html":[5,28],
 "Polygon_mesh_processing_2hole_filling_example_8cpp-example.html":[5,5],
 "Polygon_mesh_processing_2hole_filling_example_SM_8cpp-example.html":[5,6],
 "Polygon_mesh_processing_2hole_filling_visitor_example_8cpp-example.html":[5,7],
-"Polygon_mesh_processing_2interpolated_corrected_curvatures_PH_8cpp-example.html":[5,20],
-"Polygon_mesh_processing_2interpolated_corrected_curvatures_SM_8cpp-example.html":[5,19],
-"Polygon_mesh_processing_2interpolated_corrected_curvatures_vertex_8cpp-example.html":[5,21],
+"Polygon_mesh_processing_2interpolated_corrected_curvatures_PH_8cpp-example.html":[5,24],
+"Polygon_mesh_processing_2interpolated_corrected_curvatures_SM_8cpp-example.html":[5,23],
+"Polygon_mesh_processing_2interpolated_corrected_curvatures_vertex_8cpp-example.html":[5,25],
 "Polygon_mesh_processing_2isotropic_remeshing_example_8cpp-example.html":[5,18],
-"Polygon_mesh_processing_2isotropic_remeshing_with_allow_move_8cpp-example.html":[5,48],
-"Polygon_mesh_processing_2locate_example_8cpp-example.html":[5,39],
-"Polygon_mesh_processing_2manifoldness_repair_example_8cpp-example.html":[5,34],
+"Polygon_mesh_processing_2isotropic_remeshing_of_patch_example_8cpp-example.html":[5,19],
+"Polygon_mesh_processing_2isotropic_remeshing_with_allow_move_8cpp-example.html":[5,20],
+"Polygon_mesh_processing_2isotropic_remeshing_with_custom_sizing_example_8cpp-example.html":[5,21],
+"Polygon_mesh_processing_2isotropic_remeshing_with_sizing_example_8cpp-example.html":[5,22],
+"Polygon_mesh_processing_2locate_example_8cpp-example.html":[5,43],
+"Polygon_mesh_processing_2manifoldness_repair_example_8cpp-example.html":[5,38],
 "Polygon_mesh_processing_2mesh_slicer_example_8cpp-example.html":[5,17],
-"Polygon_mesh_processing_2mesh_smoothing_example_8cpp-example.html":[5,36],
+"Polygon_mesh_processing_2mesh_smoothing_example_8cpp-example.html":[5,40],
 "Polygon_mesh_processing_2orient_polygon_soup_example_8cpp-example.html":[5,14],
-"Polygon_mesh_processing_2orientation_pipeline_example_8cpp-example.html":[5,40],
+"Polygon_mesh_processing_2orientation_pipeline_example_8cpp-example.html":[5,44],
 "Polygon_mesh_processing_2point_inside_example_8cpp-example.html":[5,10],
 "Polygon_mesh_processing_2polyhedral_envelope_8cpp-example.html":[5,1],
 "Polygon_mesh_processing_2polyhedral_envelope_mesh_containment_8cpp-example.html":[5,3],
 "Polygon_mesh_processing_2polyhedral_envelope_of_triangle_soup_8cpp-example.html":[5,2],
 "Polygon_mesh_processing_2refine_fair_example_8cpp-example.html":[5,16],
-"Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html":[5,45],
-"Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html":[5,44],
-"Polygon_mesh_processing_2repair_polygon_soup_example_8cpp-example.html":[5,35],
-"Polygon_mesh_processing_2sample_example_8cpp-example.html":[5,46],
+"Polygon_mesh_processing_2remesh_almost_planar_patches_8cpp-example.html":[5,49],
+"Polygon_mesh_processing_2remesh_planar_patches_8cpp-example.html":[5,48],
+"Polygon_mesh_processing_2repair_polygon_soup_example_8cpp-example.html":[5,39],
+"Polygon_mesh_processing_2sample_example_8cpp-example.html":[5,50],
 "Polygon_mesh_processing_2self_intersections_example_8cpp-example.html":[5,4],
-"Polygon_mesh_processing_2shape_smoothing_example_8cpp-example.html":[5,37],
-"Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html":[5,47],
+"Polygon_mesh_processing_2shape_smoothing_example_8cpp-example.html":[5,41],
+"Polygon_mesh_processing_2soup_autorefinement_8cpp-example.html":[5,51],
 "Polygon_mesh_processing_2stitch_borders_example_8cpp-example.html":[5,8],
-"Polygon_mesh_processing_2tangential_relaxation_example_8cpp-example.html":[5,38],
+"Polygon_mesh_processing_2tangential_relaxation_example_8cpp-example.html":[5,42],
 "Polygon_mesh_processing_2triangulate_faces_example_8cpp-example.html":[5,11],
-"Polygon_mesh_processing_2triangulate_faces_split_visitor_example_8cpp-example.html":[5,41],
+"Polygon_mesh_processing_2triangulate_faces_split_visitor_example_8cpp-example.html":[5,45],
 "Polygon_mesh_processing_2triangulate_polyline_example_8cpp-example.html":[5,15],
-"Polygon_mesh_processing_2volume_connected_components_8cpp-example.html":[5,33],
+"Polygon_mesh_processing_2volume_connected_components_8cpp-example.html":[5,37],
 "annotated.html":[4],
 "citelist.html":[3],
 "classCGAL_1_1Polygon__mesh__processing_1_1Adaptive__sizing__field.html":[1,0,3,0],
@@ -194,7 +197,6 @@ var NAVTREEINDEX0 =
 "group__PMP__IO__grp.html#gac5b3295bd1b6375628a46d1fbaf7e881":[1,0,16,0],
 "group__PMP__combinatorial__repair__grp.html":[1,0,9],
 "group__PMP__combinatorial__repair__grp.html#ga121f588ac324938d9a6b6931a08661e1":[1,0,9,1],
-"group__PMP__combinatorial__repair__grp.html#ga152989d1d1edabb9f68296d9395eb2dd":[1,0,9,13],
 "group__PMP__combinatorial__repair__grp.html#ga1f215926ed8794db827e2993d2960870":[1,0,9,3],
 "group__PMP__combinatorial__repair__grp.html#ga25901cbedcc6123d7760ac5b9dc8d14e":[1,0,9,0],
 "group__PMP__combinatorial__repair__grp.html#ga2af4c26afc4872bafd0caabe6af23f9a":[1,0,9,6],
@@ -209,6 +211,7 @@ var NAVTREEINDEX0 =
 "group__PMP__combinatorial__repair__grp.html#ga8b9d12d817b5cc76f5a42d74eac75bf3":[1,0,9,2],
 "group__PMP__combinatorial__repair__grp.html#ga93d14c26c259b5844dbd5a7753278e5f":[1,0,9,4],
 "group__PMP__combinatorial__repair__grp.html#ga95ff13c1578f509fa8ed58b1884d0e46":[1,0,9,5],
+"group__PMP__combinatorial__repair__grp.html#gaa0ca177eb85fafc4be1f88c5b27c25bd":[1,0,9,13],
 "group__PMP__combinatorial__repair__grp.html#gaef5c13fc9dd4cae14c860351c479a45f":[1,0,9,10],
 "group__PMP__corefinement__grp.html":[1,0,12],
 "group__PMP__corefinement__grp.html#ga02fa6ed9116a759ecfb87063392f5455":[1,0,12,11],
@@ -246,8 +249,5 @@ var NAVTREEINDEX0 =
 "group__PMP__geometric__repair__grp.html":[1,0,10],
 "group__PMP__geometric__repair__grp.html#ga2abeabce0ee6906cd274570fcc38c146":[1,0,10,1],
 "group__PMP__geometric__repair__grp.html#ga48008d2b66de8a68a7068f29db15dad6":[1,0,10,0],
-"group__PMP__geometric__repair__grp.html#ga571b1605486d5cec0f4474aae3fa1905":[1,0,10,2],
-"group__PMP__geometric__repair__grp.html#ga91c02ef57e638faf2622eae93e7a25e2":[1,0,10,3],
-"group__PMP__hole__filling__grp.html":[1,0,2],
-"group__PMP__hole__filling__grp.html#ga18eac756a8f8e5d5f73e645fd4e26cad":[1,0,2,7]
+"group__PMP__geometric__repair__grp.html#ga571b1605486d5cec0f4474aae3fa1905":[1,0,10,2]
 };
